@@ -37,6 +37,7 @@ OC.L10N.register(
     "Comment:" : "Коментар:",
     "You have a new appointment booking \"%s\" from %s" : "Имате нова резервация за среща „%s“ от %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Уважаемият/та  %s, %s (%s) резервира среща с вас.",
+    "Location:" : "Местоположение:",
     "A Calendar app for Nextcloud" : "Календар за Nextcloud",
     "Previous day" : "Вчера",
     "Previous week" : "Миналата седмица",
@@ -104,7 +105,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Елементите в кошчето за боклук се изтриват след {numDays} дни","Елементите в кошчето се изтриват след {numDays} дни"],
     "Could not update calendar order." : " Невъзможност да се актуализира записът в календара",
     "Deck" : "Deck",
-    "Hidden" : "Скрит",
     "An error occurred, unable to publish calendar." : "Възникна грешка, невъзможност да се публикува календар.",
     "An error occurred, unable to send email." : "Възникна грешка, невъзможност да се изпрати имейл",
     "Embed code copied to clipboard." : "Кодът за вграждане е копиран в клипборда",
@@ -127,10 +127,11 @@ OC.L10N.register(
     "Unshare with {displayName}" : "Прекратява споделянето с {displayName}",
     "Share with users or groups" : "Сподели с потребители или групи",
     "No users or groups" : "Няма потребители или групи",
-    "Calendar name …" : "Име на календар ...",
     "Share calendar" : "Споделяне на календар",
     "Unshare from me" : "Прекратяване на споделянето от мен",
     "Save" : "Запазване",
+    "No title" : "Без заглавие",
+    "View" : "Изглед",
     "Import calendars" : "Импортиране на календари",
     "Please select a calendar to import into …" : "Моля, изберете календар, в който да импортирате",
     "Filename" : "Име на файла",
@@ -147,8 +148,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно импортиране на %n събития","Успешно импортиране на %n събития"],
     "Import partially failed. Imported {accepted} out of {total}." : "Импортирането е частично неуспешно. Импортирани {accepted} от {total}.",
     "Automatic" : "Автоматично",
-    "Automatic ({detected})" : "Автоматично (detected})",
+    "Automatic ({timezone})" : "Автоматично ({timezone})",
     "New setting was not saved successfully." : " Неуспешно запазване на новата настройка.",
+    "Timezone" : "Часови пояс",
     "Navigation" : "Навигация",
     "Previous period" : "Предишен период",
     "Next period" : "Следващ период",
@@ -165,24 +167,22 @@ OC.L10N.register(
     "Save edited event" : "Запиши редактираното събитие",
     "Delete edited event" : "Изтриване на редактираното събитие",
     "Duplicate event" : "Дублирано събитие",
-    "Shortcut overview" : "Преглед на пряк път",
     "or" : "или",
     "Calendar settings" : "Настройки на календар",
     "No reminder" : "Без напомняне",
     "CalDAV link copied to clipboard." : "Копиране на CalDAV връзка в клипборда",
     "CalDAV link could not be copied to clipboard." : "CalDAV връзката не може да бъде копирана в клипборда",
-    "Enable birthday calendar" : "Активиране на календара за рожден ден",
-    "Show tasks in calendar" : "Показване на задачите в календара",
-    "Enable simplified editor" : "Активиране на опростен редактор",
-    "Limit the number of events displayed in the monthly view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
-    "Show weekends" : "Покажи събота и неделя",
-    "Show week numbers" : "Показвай номерата на седмиците",
-    "Time increments" : "Времеви стъпки",
-    "Default reminder" : "Напомняне по подразбиране",
+    "General" : "Общи",
+    "Personal availability settings" : "Настройки за лична достъпност",
     "Copy primary CalDAV address" : "Копиране на основния CalDAV адрес",
     "Copy iOS/macOS CalDAV address" : "Копиране iOS/macOS CalDAV адрес",
-    "Personal availability settings" : "Настройки за лична достъпност",
-    "Show keyboard shortcuts" : "Показване на клавишни комбинации",
+    "Enable birthday calendar" : "Активиране на календара за рожден ден",
+    "Show tasks in calendar" : "Показване на задачите в календара",
+    "Show weekends" : "Покажи събота и неделя",
+    "Show week numbers" : "Показвай номерата на седмиците",
+    "Editing" : "Редактиране",
+    "Default reminder" : "Напомняне по подразбиране",
+    "Keyboard shortcuts" : "Бързи клавиши",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} минути","{duration} минути"],
     "0 minutes" : "0 минути",
     "_{duration} hour_::_{duration} hours_" : ["{duration} часа","{duration} минути"],
@@ -347,6 +347,11 @@ OC.L10N.register(
     "Update this occurrence" : "Актуализиране на това събитие",
     "Public calendar does not exist" : "Публичният календар не съществува",
     "Maybe the share was deleted or has expired?" : "Може би споделянето е изтрито или е изтекло?",
+    "Yes" : "Да",
+    "No" : "Не",
+    "Maybe" : "Може би",
+    "None" : "Няма",
+    "Create" : "Създаване",
     "from {formattedDate}" : "от {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
     "on {formattedDate}" : "на {formattedDate}",
@@ -392,6 +397,11 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прикачени файлове, изискващи споделен достъп","Прикачени файлове, изискващи споделен достъп"],
     "Untitled event" : "Събитие без заглавие",
     "Close" : "Затвори",
+    "Selected" : "Избранo",
+    "Title" : "Заглавие",
+    "30 min" : "30 мин",
+    "Participants" : "Участници",
+    "Submit" : "Изпращане",
     "Subscribe to {name}" : "Абониране за {name}",
     "Export {name}" : "Експортиране /изнасям/ на {name}",
     "Anniversary" : "Годишнина",
@@ -482,6 +492,14 @@ OC.L10N.register(
     "Imported {filename}" : "Импортирано {filename}",
     "This is an event reminder." : "Това е напомняне за събитие.",
     "Appointment not found" : "Срещата не е намерена",
-    "User not found" : "Потребителят не е намерен "
+    "User not found" : "Потребителят не е намерен ",
+    "Hidden" : "Скрит",
+    "Calendar name …" : "Име на календар ...",
+    "Automatic ({detected})" : "Автоматично (detected})",
+    "Shortcut overview" : "Преглед на пряк път",
+    "Enable simplified editor" : "Активиране на опростен редактор",
+    "Limit the number of events displayed in the monthly view" : "Ограничаване на броя на събитията, показвани в месечния изглед",
+    "Time increments" : "Времеви стъпки",
+    "Show keyboard shortcuts" : "Показване на клавишни комбинации"
 },
 "nplurals=2; plural=(n != 1);");
