@@ -37,7 +37,16 @@ OC.L10N.register(
     "Comment:" : "Kommentti:",
     "You have a new appointment booking \"%s\" from %s" : "Sinulla on uusi tapaamisvaraus \"%s\" henkilöltä %s",
     "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) varasi tapaamisen kanssasi.",
+    "%s has proposed a meeting" : "%s ehdotti tapaamista",
+    "%s has updated a proposed meeting" : "%s päivitti kokousehdotuksen",
+    "%s has canceled a proposed meeting" : "%s perui kokousehdotuksen",
+    "Dear %s, a new meeting has been proposed" : "%s, uutta kokousta on ehdotettu",
+    "Dear %s, a proposed meeting has been updated" : "%s, ehdotettu kokous on päivitetty",
+    "Dear %s, a proposed meeting has been cancelled" : "%s, ehdotettu kokous on peruttu",
     "Location:" : "Sijainti:",
+    "Duration:" : "Kesto:",
+    "Dates:" : "Päivät:",
+    "Respond" : "Vastaa",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -111,7 +120,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Kalenterin järjestystä ei voitu päivittää.",
     "Shared calendars" : "Jaetut kalenterit",
     "Deck" : "Pakka",
-    "Hidden" : "Piilotettu",
     "Internal link" : "Sisäinen linkki",
     "A private link that can be used with external clients" : "Yksityinen linkki, jota voi käyttää ulkoisten asiakkaiden kanssa",
     "Copy internal link" : "Kopioi sisäinen linkki",
@@ -139,11 +147,17 @@ OC.L10N.register(
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "Failed to save calendar name and color" : "Kalenterin nimen ja värin tallentaminen epäonnistui",
-    "Calendar name …" : "Kalenterin nimi…",
     "Share calendar" : "Jaa kalenteri",
     "Unshare from me" : "Lopeta jako minulle",
     "Save" : "Tallenna",
     "No title" : "Ei otsikkoa",
+    "Are you sure you want to delete \"{title}\"?" : "Haluatko varmasti poistaa \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Poistetaan ehdotus \"{title}\"",
+    "Successfully deleted proposal" : "Ehdotus poistettu",
+    "Failed to delete proposal" : "Ehdotuksen poistaminen epäonnistui",
+    "Failed to retrieve proposals" : "Ehdotusten noutaminen epäonnistui",
+    "Meeting proposals" : "Kokousehdotukset",
+    "No active meeting proposals" : "Ei aktiivisia kokousehdotuksia",
     "View" : "Näkymä",
     "Import calendars" : "Tuo kalenterit",
     "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
@@ -161,7 +175,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa"],
     "Import partially failed. Imported {accepted} out of {total}." : "Tuonti epäonnistui osittain. Tuotiin {accepted}/{total}.",
     "Automatic" : "Automaattinen",
-    "Automatic ({detected})" : "Automaattinen ({detected})",
+    "Automatic ({timezone})" : "Automaattinen ({timezone})",
     "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
     "Timezone" : "Aikavyöhyke",
     "Navigation" : "Navigointi",
@@ -192,10 +206,12 @@ OC.L10N.register(
     "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
     "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
     "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
+    "View options" : "Näkymävalinnat",
     "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
     "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
     "Show weekends" : "Näytä viikonloput",
     "Show week numbers" : "Näytä viikkonumerot",
+    "Limit number of events shown in month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
     "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
     "Default reminder" : "Oletusmuistutus",
     "Keyboard shortcuts" : "Pikanäppäimet",
@@ -250,10 +266,15 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Tapaamista ei voitu kirjata. Ole hyvä ja yritä myöhemmin uudelleen tai ota yhteyttä järjestäjään.",
     "Back" : "Takaisin",
     "Book appointment" : "Varaa tapaaminen",
+    "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
+    "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
+    "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
     "Error creating Talk conversation" : "Virhe luotaessa Talk-keskustelua",
     "Select a Talk Room" : "Valitse Talk-huone",
     "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
+    "No Talk room available" : "Talk-huonetta ei ole käytettävissä",
+    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
     "Select conversation" : "Valitse keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
@@ -277,6 +298,7 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "Attachment {name} already exist!" : "Liite {name} on jo olemassa!",
     "Could not upload attachment(s)" : "Liitteiden lähetys epäonnistui",
+    "You are about to download a file. Please check the file name before opening it. Are you sure to proceed?" : "Olet aikeissa ladata tiedoston. Tarkista tiedoston nimi ennen sen avaamista. Haluatko jatkaa?",
     "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Olet aikeissa siirtyä kohteeseen {host}. Haluatko varmasti jatkaa? Linkki: {link}",
     "Proceed" : "Jatka",
     "No attachments" : "Ei liitteitä",
@@ -301,6 +323,7 @@ OC.L10N.register(
     "Awaiting response" : "Odottaa vastausta",
     "Checking availability" : "Tarkistetaan saatavuutta",
     "Has not responded to {organizerName}'s invitation yet" : "Ei ole vielä vastanut järjestäjän {organizerName} kutsuun",
+    "Suggested times" : "Ehdotetut ajat",
     "chairperson" : "puheenjohtaja",
     "required participant" : "vaadittu osallistuja",
     "optional participant" : "valinnainen osallistuja",
@@ -308,6 +331,8 @@ OC.L10N.register(
     "{attendee} ({role})" : "{attendee} ({role})",
     "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
     "Suggestion accepted" : "Ehdotus hyväksytty",
+    "Previous date" : "Edellinen päivä",
+    "Next date" : "Seuraava päivä",
     "Legend" : "Selite",
     "Out of office" : "Ulkona toimistolta",
     "Attendees:" : "Osallistujat:",
@@ -395,9 +420,14 @@ OC.L10N.register(
     "Update this occurrence" : "Päivitä tämä esiintymä",
     "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
     "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
+    "Attendance required" : "Osallistuminen vaaditaan",
+    "Attendance optional" : "Osallistuminen valinnaista",
+    "Remove participant" : "Poista osallistuja",
     "Yes" : "Kyllä",
     "No" : "Ei",
     "Maybe" : "Ehkä",
+    "None" : "Ei mitään",
+    "Create a meeting for this date and time" : "Luo kokous tälle päivälle ja ajankohdalle",
     "Create" : "Luo",
     "from {formattedDate}" : "alkaen {formattedDate}",
     "to {formattedDate}" : "päättyen {formattedDate}",
@@ -439,6 +469,9 @@ OC.L10N.register(
     "Personal" : "Henkilökohtainen",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automaattinen aikavyöhykkeentunnistus määritti aikavyöhykkeesi olevan UTC. \nTämä johtuu todennäköisesti selaimesi tietoturva-asetuksista.\nOle hyvä ja aseta aikavyöhykkeesi manuaalisesti kalenterin asetuksista.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
+    "Show unscheduled tasks" : "Näytä ajastamattomat tehtävät",
+    "Unscheduled tasks" : "Ajastamattomat tehtävät",
+    "Discard event" : "Hylkää tapahtuma",
     "Edit event" : "Muokkaa tapahtumaa",
     "Event does not exist" : "Tapahtumaa ei ole olemassa",
     "Delete this occurrence" : "Poista tämä esiintymä",
@@ -447,13 +480,40 @@ OC.L10N.register(
     "Managing shared access" : "Jaetun pääsyn hallinta",
     "Deny access" : "Estä pääsy",
     "Invite" : "Kutsu",
+    "Discard changes?" : "Hylätäänkö muutokset?",
+    "Are you sure you want to discard the changes made to this event?" : "Haluatko varmasti hylätä tähän tapahtumaan tehdyt muutokset?",
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
+    "Meeting proposals overview" : "Kokousehdotusten yhteenveto",
+    "Edit meeting proposal" : "Muokkaa kokousehdotusta",
+    "Create meeting proposal" : "Luo kokousehdotus",
+    "Update meeting proposal" : "Päivitä kokousehdotus",
+    "Saving proposal \"{title}\"" : "Tallennetaan ehdotus \"{title}\"",
+    "Successfully saved proposal" : "Ehdotus tallennettu",
+    "Failed to save proposal" : "Ehdotuksen tallentaminen epäonnistui",
+    "Creating meeting for {date}" : "Luo kokous päivälle {date}",
+    "Please enter a valid duration in minutes." : "Kirjoita kelvollinen kesto minuutteina.",
+    "Failed to fetch proposals" : "Ehdotusten noutaminen epäonnistui",
     "Selected" : "Valittu",
+    "No Description" : "Ei kuvausta",
+    "No Location" : "Ei sijaintia",
+    "Edit this meeting proposal" : "Muokkaa tätä kokousehdotusta",
+    "Delete this meeting proposal" : "Poista tämä kokousehdotus",
     "Title" : "Nimeke",
+    "15 min" : "15 min",
     "30 min" : "30 min",
+    "60 min" : "60 min",
+    "90 min" : "90 min",
     "Participants" : "Osallistujat",
+    "Selected times" : "Valitut ajat",
+    "Loading meeting proposal" : "Ladataan kokousehdotusta",
+    "No meeting proposal found" : "Kokousehdotusta ei löytynyt",
+    "Thank you for your response!" : "Kiitos vastauksestasi!",
+    "Unknown User" : "Tuntematon käyttäjä",
+    "No Title" : "Ei otsikkoa",
+    "No Duration" : "Ei kestoa",
+    "Select a different time zone" : "Valitse eri aikavyöhyke",
     "Submit" : "Lähetä",
     "Subscribe to {name}" : "Tilaa {name}",
     "Export {name}" : "Vie {name}",
@@ -510,6 +570,7 @@ OC.L10N.register(
     "W" : "Vko",
     "%n more" : "%n lisää",
     "No events to display" : "Ei tapahtumia näytettäväksi",
+    "All participants declined" : "Kaikki osallistujat kieltäytyivät",
     "Please confirm your participation" : "Vahvista osallistumisesi",
     "You declined this event" : "Kieltäydyit tästä tapahtumasta",
     "Your participation is tentative" : "Osallistumisesi on alustava.",
@@ -546,6 +607,8 @@ OC.L10N.register(
     "Error while sharing file with user" : "Virhe tiedostoa jakaessa käyttäjän kanssa",
     "Error creating a folder {folder}" : "Virhe luotaessa kansiota {folder}",
     "Attachment {fileName} already exists!" : "Liite {fileName} on jo olemassa!",
+    "Attachment {fileName} added!" : "Liite {fileName} lisätty!",
+    "An error occurred during uploading file {fileName}" : "Tiedostoa {fileName} lähettäessä tapahtui virhe",
     "An error occurred during getting file information" : "Tiedostojen tietoja noutaessa tapahtui virhe",
     "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
@@ -553,6 +616,9 @@ OC.L10N.register(
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
     "User not found" : "Käyttäjää ei löydy",
+    "Hidden" : "Piilotettu",
+    "Calendar name …" : "Kalenterin nimi…",
+    "Automatic ({detected})" : "Automaattinen ({detected})",
     "Shortcut overview" : "Pikakuvakenäkymä",
     "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
     "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
