@@ -23,21 +23,26 @@ OC.L10N.register(
     "Edit" : "Ẓreg",
     "Delete" : "Kkes",
     "Create new" : "Snulfu-d amaynut",
+    "Calendars" : "Iwitayen",
     "Add new" : "Rnu amaynut",
     "New calendar" : "Awitay amaynut",
     "Name" : "Isem",
     "Deleted" : "Yettwakkes",
+    "Delete permanently" : "Kkes-it i lebda",
     "Share link" : "Bḍu aseɣwen",
     "Save" : "Sekles",
     "Filename" : "Isem n ufaylu",
     "Cancel" : "Semmet",
+    "Navigation" : "Tunigin",
     "List view" : "Timeẓri n tebdart",
     "Actions" : "Tigawin",
     "Editor" : "Amaẓrag",
     "Close editor" : "Mdel amaẓrag",
     "or" : "neɣ",
     "General" : "Amatu",
+    "Keyboard shortcuts" : "Inegzumen n unasiw",
     "Location" : "Adig",
+    "Description" : "Aglam",
     "Add" : "Rnu",
     "Monday" : "Arim",
     "Tuesday" : "Aram",
@@ -54,6 +59,7 @@ OC.L10N.register(
     "Proceed" : "Kemmel",
     "Delete file" : "Kkes afaylu",
     "Done" : "Immed",
+    "Busy" : "Ur yestuf ara",
     "Unknown" : "Arussin",
     "Yes" : "Ih",
     "No" : "Uhu",
@@ -67,6 +73,7 @@ OC.L10N.register(
     "Daily" : "S wass",
     "Weekly" : "S umalas",
     "Other" : "Wayeḍ",
-    "Status" : "Addad"
+    "Status" : "Addad",
+    "Categories" : "Taggayin"
 },
 "nplurals=2; plural=(n != 1);");
